October 26, 2016, 03:18 (GMT) |
BMesh: edge-net split, edge selection error In practice I couldn't make this cause a bug, however it's a logical regression in fix for T48716. Thanks to Francesc Juhe for finding. |
October 25, 2016, 23:38 (GMT) |
fix edge shader input |
October 25, 2016, 23:34 (GMT) |
OpenGL: new mesh draw routines for new viewport Totally WIP. Started with copies of legacy routines, modified to use the new shaders & batch cache. Not all features are implemented; this is why we keep legacy viewport around during development! |
October 25, 2016, 19:11 (GMT) |
Merge branch 'master' into fluid-mantaflow |
October 25, 2016, 17:49 (GMT) |
[msvc] make.bat - create a build.log in the build directory |
October 25, 2016, 16:29 (GMT) |
Cycles: Fix for fix (tm) Sorry guys, for some reason read the expression back-to-front and did wrong fix :S |
October 25, 2016, 16:06 (GMT) |
Cycles: Fix typo in previous commit for BVH improvements |
October 25, 2016, 15:59 (GMT) |
Fix T49815: Blender always reverts to RGBA when using Save As Image. `BKE_imformat_defaults()` was doing some weird black magic based on imbuf's channels, instead of merely copying imbuf's planes here... |
October 25, 2016, 15:36 (GMT) |
Cycles: Replace OpenCL atomic functions with own versions |
October 25, 2016, 15:36 (GMT) |
Cycles: Replace OpenCL work item functions with own versions |
October 25, 2016, 15:34 (GMT) |
API: Fix Links Self-explanatory. to find broken links run `sphinx-build -b linkcheck sphinx-in sphinx-out` Reviewers: mont29 Tags: #bf_blender, #python, #infrastructure:_websites Differential Revision: https://developer.blender.org/D2297 |
October 25, 2016, 14:53 (GMT) |
Partial fix for T49836: Camera DOF properties not updating via graph editor Do this for the new dependency graph: was missing handle of OB_UPDATE_TIME in tag update. Hopefully it's all correct still. Old dependency graph needs work, but i'm tempting to call it unsupported and move on to 2.8 branch. |
October 25, 2016, 14:10 (GMT) |
Cycles: Enable SSE math optimization for AVX kernels This gives about 5% speedup for AVX processors. Benefit of such optimization on other microarchitectures is still under investigation. |
October 25, 2016, 13:27 (GMT) |
Cycles: Use new SSE version of offset calculation for all QBVH flavors Gives up to ~1% speedup again. While it seems to be small, still nice since the code now is actually more clean that it used to be before. |
October 25, 2016, 13:09 (GMT) |
Cycles: Rearrange split kernel code to move all logic out of OpenCL kernel files We need all logic in a place that can be used when building for other devices besides OpenCL. This leaves things a little messy at the moment, code deduplication and general clean up can happen later. |
October 25, 2016, 13:08 (GMT) |
Cycles: Move QBVH near/far offset calculation to an utility function Just preparing for new optimization to be used in all traversal implementation. Should be no measurable difference. |
October 25, 2016, 12:49 (GMT) |
Cycles: Add code to register kernel functions Makes it easy to retrieve kernel functions for different architectures without needing large ifdef chains everywhere. |
October 25, 2016, 12:47 (GMT) |
Cycles: BVH-related SSE optimization Several ideas here: - Optimize calculation of near_{x,y,z} in a way that does not require 3 if() statements per update, which avoids negative effect of wrong branch prediction. - Optimization of direction clamping for BVH. - Optimization of point/direction transform. Brings ~1.5% speedup again depending on a scene (unfortunately, this speedup can't be sum across all previous commits because speedup of each of the changes varies from scene to scene, but it still seems to be nice solid speedup of few percent on Linux and bigger speedup was reported on Windows). Once again ,thanks Maxym for inspiration! Still TODO: We have multiple places where we need to calculate near x,y,z indices in BVH, for now it's only done for main BVH traversal. Will try to move this calculation to an utility function and see if that can be easily re-used across all the BVH flavors. |
October 25, 2016, 12:18 (GMT) |
Cycles: Avoid branching in SSE version of intersection pre-calculation Similar to the previous commit, avoid negative effect of bad branch prediction. Gives measurable performance up to ~2% in tests here. Once again, thanks to Maxym Dmytrychenko! |
October 25, 2016, 11:54 (GMT) |
Cycles: Implement SSE-optimized path of util_max_axis() The idea here is to avoid if statements which could cause wrong branch prediction. Gives a bit of measurable speedup up to ~1%. Still nice :) Inspired by Maxym Dmytrychenko, thanks! |
|
|
|


Master Commits
MiikaH:n Sivut a.k.a. MiikaHweb | 2003-2021